#Import ggplot2 and other useful ready-made code
library("tidyverse")

########## Part1 A Simple Plot ##########

#Import our 2022 country data
chi22 <- read.csv2("chi22-country.csv",sep=",")

# Plot 1a - a very simple plot
# What happens if you change the 'x' to a 'y' and the 'y' to an 'x'?  
ggplot(data = chi22, mapping = aes(x=Country, y=Pubs)) +
  geom_point() +
  coord_flip()

# Plot 1b - modified to get the data ranked from high to low
ggplot(data = chi22, mapping = aes(x=reorder(Country, Pubs), y=Pubs)) +
  geom_point() +
  coord_flip()

# Plot 1c - with useful labels
ggplot(data = chi22, mapping = aes(x=reorder(Country, Pubs), y=Pubs)) +
  geom_col() +
  coord_flip() +
  labs(x="Number of CHI 2021 Publications", 
       y="Country",
       title="CHI 2021 Publications",
       subtitle="Papers track")

# Plot 1d - change from geom_point to geom_col
ggplot(data = chi22, mapping = aes(x=reorder(Country, Pubs), y=Pubs)) +
  geom_col() +
  coord_flip()

# Plot 1e - back to geom_point and now also adding a colour and size to our geom_point
ggplot(data = chi22, mapping = aes(x=reorder(Country, Pubs), y=Pubs)) +
  geom_point(colour="Orange",size=3) +
  coord_flip()

# Plot 1f - change from geom_point to geom_col
ggplot(data = chi22, mapping = aes(x=reorder(Country, Pubs), y=Pubs)) +
  geom_col(fill="Orange") +
  coord_flip()

# Plot 1g - back to geom_point and now also adding a colour and size to our geom_point
ggplot(data = chi22, mapping = aes(x=reorder(Country, Pubs), y=Pubs)) +
  geom_point(colour="Orange",size=3) +
  coord_flip() +
  theme_minimal()

# Plot 1h - back to geom_point and now also adding a colour and size to our geom_point
ggplot(data = chi22, mapping = aes(x=reorder(Country, Pubs), y=Pubs)) +
  geom_point(colour="Orange",size=3) +
  coord_flip() +
  theme_minimal() +
  theme(panel.grid.major.x = element_line(colour="darkslategrey", size=0.3), 
        panel.grid.major.y = element_blank(),
        panel.grid.minor.x = element_blank(),
        axis.text.x = element_text(size=14,colour="darkslategrey"))

########## Part 2 Multiple Variables ##########

# Importing additional data
chimbined <- read.csv2("combined-chi.csv",sep=",")

#Plot 3a plotting multiple years of CHI papers
ggplot(data = chimbined, mapping = aes(x=reorder(Country, Pubs), y=Pubs, colour=factor(Year))) +
  geom_point(size=3) +
  coord_flip()

#Plot 3b now with shapes instead of colours
ggplot(data = chimbined, mapping = aes(x=reorder(Country, Pubs), y=Pubs, shape=factor(Year))) +
  geom_point(size=3) +
  coord_flip()

#Plot 3c With custom colours
ggplot(data = chimbined, mapping = aes(x=reorder(Country, Pubs), y=Pubs, colour=factor(Year))) +
  geom_point(size=3) +
  coord_flip() +
  scale_colour_manual(values=c("2022"="Red","2021"="Green")) 



########## Part 3 Mapping Submissions ##########

#Import mapping libraries
library(maps)

# Import the map of the world and add our CHI countries to it
world <- map_data("world")
world$fac <- world$region %in% chi22$Country

#Plot 3a, a simple plot of countries of the world
ggplot(data = world, aes(x=long, y = lat, group = group)) +
  geom_polygon(colour="white")

#Plot 3b, countries of the world with CHI papers
ggplot(data = world, aes(x=long, y = lat, group = group)) +
  geom_polygon(aes(fill=fac),colour="white")

### Plot 3c, with constrained porportions
ggplot(data = world, aes(x=long, y = lat, group = group)) +
  geom_polygon(aes(fill=fac),colour="white", size=0.1)+
  coord_fixed(1.3)

### Plot 3d Full, tidy plot
ggplot(data = world, aes(x=long, y = lat, group = group)) +
  geom_polygon(aes(fill=fac),colour="white", size=0.1)+
  coord_fixed(1.3) + 
  guides(fill="none") +
  theme(
    axis.text = element_blank(),
    axis.line = element_blank(),
    axis.ticks = element_blank(),
    panel.border = element_blank(),
    panel.grid = element_blank(),
    axis.title = element_blank()
  )

#Plot 3x, an alternative way of plotting, using geom_map

world <- map_data("world")
papersbyregion <- data.frame("region"=world$region,"haspaper"=world$region %in% chi22$Country)

ggplot(data=papersbyregion, aes(map_id=region)) +
  geom_map(aes(fill = haspaper), map=world) +
  expand_limits(x = world$long, y = world$lat)